def add_health_seeking(
        start_day: int = 1,
        targets: list = None,
        drug: list = None,
        node_ids: list = None,
        ind_property_restrictions: list = None,
        drug_ineligibility_duration: int = 0,
        duration: int = -1,
        broadcast_event_name: str = 'ReceivedTreatment'):
    """
    Add a health seeking behavior intervention to the campaign using using
    the **NodeLevelHealthTriggeredIV** class, a node-level intervention.
    The intervention will distribute drugs to targeted individuals within
    the node.

    Args:
        start_day: Start day of intervention.
        targets: List of dictionaries defining the trigger event and coverage for and
        properties of individuals to target with the intervention. Default is ``[{
            "trigger":"NewClinicalCase","coverage":0.8,"agemin":15,"agemax":70,
            "seek":0.4,"rate":0.3},{"trigger":"NewSevereCase","coverage":0.8,"seek":0.6,
            "rate":0.5}]``.
        drug: List of drug(s) to administer. Default is ``["Artemether","Lumefantrine"]``.
        node_ids: The list of nodes to apply this intervention to (**Node_List**
            parameter). If not provided, set value of NodeSetAll.
        ind_property_restrictions: List of IndividualProperty key:value pairs that
            individuals must have to receive the intervention. For example,
            ``[{"IndividualProperty1":"PropertyValue1"}, {"IndividualProperty2":
            "PropertyValue2"}]``.
        drug_ineligibility_duration: Sets a drug ineligibility duration (number of days).
            If set to > 0, use IndividualProperties to prevent people from receiving
            drugs too frequently. Demographics file will need to define the IP DrugStatus
            with possible values None and RecentDrug. Individuals with status RecentDrug
            will not receive drugs during drug campaigns, though they are still eligible
            for receiving diagnostics (in MSAT, etc). Individuals who receive drugs during
            campaigns will have their DrugStatus changed to RecentDrug for drug
            ineligibility duration.
        duration: How long the intervention is active. Default is -1, where intervention
            never expires.
        broadcast_event_name: Event to broadcast when successful health seeking behavior.
            Default is Received_Treatment.

    Returns:
        None
    """

    import emod_api.campaign as camp
    import emodpy_malaria.interventions.treatment_seeking as ts

    ts.add(camp, start_day=start_day,
           targets=targets,
           drug=drug,
           node_ids=node_ids,
           ind_property_restrictions=ind_property_restrictions,
           drug_ineligibility_duration=drug_ineligibility_duration,
           duration=duration,
           broadcast_event_name=broadcast_event_name)

    return camp
