def add_InputEIR(simulation, monthlyEIRs, age_dependence="SURFACE_AREA_DEPENDENT", start_day=0, nodeIDs=None,
                 ind_property_restrictions=None):
    """
    Create an intervention introducing new malaria infections using the
    **InputEIR** class. If another InputEIR event is distributed to a node
    with an existing InputEIR event, the second one replaces the first (much
    like a new bednet replaces an old bednet).

    Args:
        simulation: idmtools Simulation
        monthlyEIRs: A list of monthly EIRs (must contain 12 items).
        age_dependence: The effect of EIR based on age. Accepted
        values are LINEAR or SURFACE_AREA_DEPENDENT.
        start_day: The day to distribute new infections (**Start_Day**
            parameter).
        nodeIDs: The list of nodes to apply this intervention to (**Node_List**
            parameter). If not provided, set value of NodeSetAll.
        ind_property_restrictions: The IndividualProperty key:value pairs to
            target (**Property_Restrictions_Within_Node** parameter). In the
            format ``[{"IndividualProperty1" : "PropertyValue1"},
            {'IndividualProperty2': "PropertyValue2"}, ...]``

    Returns:
        None
    """

    if ind_property_restrictions is None:
        ind_property_restrictions = []

    if len(monthlyEIRs) != 12:
        raise Exception('The input argument monthlyEIRs should have 12 entries, not %d' % len(monthlyEIRs))

    import emod_api.campaign as camp
    import emodpy_malaria.interventions.inputeir as eir
    input_EIR_event = eir.InputEIR(camp, monthly_eir=monthlyEIRs, start_day=start_day, node_ids=nodeIDs,
                                   age_dependence=age_dependence)
    if ind_property_restrictions:
        input_EIR_event["Event_Coordinator_Config"]["Intervention_Config"][
            "Property_Restrictions_Within_Node"] = ind_property_restrictions
    simulation.task.campaign.add_event(input_EIR_event)
