import sys


def add_summary_report(simulation, start=0, interval=365,
                       description='AnnualAverage',
                       duration_days=100000,
                       age_bins=None,
                       parasitemia_bins=None,
                       infection_bins=None,
                       nreports=10000,
                       nodes=None,
                       ipfilter=""):
    if not age_bins:
        age_bins = [1.0 / 12, 0.5, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
                    11, 12, 13, 14, 15, 20, 25, 30, 40, 50, 60, 125]
    if not parasitemia_bins:
        parasitemia_bins = [50.0, 500.0, 5000.0, sys.maxsize]
    if not infection_bins:
        infection_bins = [20.0, 40.0, 60.0, 80.0, 100.0]
    if not nodes:
        nodes = {"class": "NodeSetAll"}

    from emodpy_malaria.reporters.builtin import MalariaSummaryReport
    summary_report = MalariaSummaryReport()

    def msr_config_builder(params):
        params.Start_Day = start
        params.Age_Bins = age_bins
        params.Duration_Days = duration_days
        params.Reporting_Interval = interval
        params.Infectiousness_Bins = infection_bins
        params.Max_Number_Reports = nreports
        params.Parasitemia_Bins = parasitemia_bins
        params.Report_Description = description
        params.Nodeset_Config = nodes
        params.Individual_Property_Filter = ipfilter

        return params

    from emodpy_calibra.malaria_params_cache import manifest
    summary_report.config(msr_config_builder, manifest)
    simulation.task.reporters.add_reporter(summary_report)
