from emodpy_calibra.malaria.interventions.health_seeking import add_health_seeking
from emodpy_calibra.malaria.reports.malaria_report import add_summary_report
from emodpy_calibra.malaria.site.input_eir_by_site import configure_site_EIR


class update_params:
    def __init__(self, params):
        self.params = params

    def __call__(self, simulation):
        for key, value in self.params.items():
            setattr(simulation.task.config.parameters, key, value)


class config_setup_fn:
    def __init__(self, duration=21915):
        self.duration = duration

    def __call__(self, simulation):
        simulation.task.config.parameters.Simulation_Duration = self.duration
        simulation.task.config.parameters.Infection_Updates_Per_Timestep = 8
        return {'Simulation_Duration': self.duration, 'Infection_Updates_Per_Timestep': 8}


# reporters
class summary_report_fn:
    def __init__(self, start=1, interval=365, nreports=2000, age_bins=[1000],
                 parasitemia_bins=[0, 50, 500, 5000, 5000000], infection_bins=[0, 5, 20, 50, 80, 100],
                 description='Annual_Report', nodes=None, ipfilter=None):
        self.start = start
        self.interval = interval
        self.nreports = nreports
        self.age_bins = age_bins or [1000]
        self.parasitemia_bins = parasitemia_bins
        self.infection_bins = infection_bins
        self.description = description
        self.nodes = nodes or {"class": "NodeSetAll"}
        self.ip_filter = "" if not ipfilter else ipfilter

    def __call__(self, simulation):
        return add_summary_report(simulation, start=self.start, interval=self.interval, nreports=self.nreports,
                                  description=self.description, age_bins=self.age_bins,
                                  parasitemia_bins=self.parasitemia_bins, infection_bins=self.infection_bins,
                                  nodes=self.nodes, ipfilter=self.ip_filter)


# health-seeking
class add_treatment_fn:
    def __init__(self, start_day: int = 1,
                 targets: list = None,
                 drug: list = None,
                 node_ids: list = None,
                 ind_property_restrictions: list = None,
                 drug_ineligibility_duration: int = 0,
                 duration: int = -1,
                 broadcast_event_name: str = 'ReceivedTreatment'):
        self.start_day = start_day
        self.targets = targets
        self.drug = drug
        self.node_ids = node_ids
        self.ind_property_restrictions = ind_property_restrictions
        self.drug_ineligibility_duration = drug_ineligibility_duration
        self.duration = duration
        self.broadcast_event_name = broadcast_event_name

    def __call__(self, simulation):
        return self.fn(simulation)

    def fn(self, simulation):
        camp = add_health_seeking(start_day=self.start_day, targets=self.targets, drug=self.drug,
                                  node_ids=self.node_ids, ind_property_restrictions=self.ind_property_restrictions,
                                  drug_ineligibility_duration=self.drug_ineligibility_duration, duration=self.duration,
                                  broadcast_event_name=self.broadcast_event_name)
        events = camp.campaign_dict["Events"]
        simulation.task.campaign.add_events(events)

        from emodpy_calibra.malaria.utility.campain import post_add_camp
        post_add_camp(simulation, camp)


# input EIR
class site_input_eir_fn:
    def __init__(self, site, birth_cohort=True, set_site_geography=False):
        self.site = site
        self.birth_cohort = birth_cohort
        self.set_site_geography = set_site_geography

    def __call__(self, simulation):
        return configure_site_EIR(simulation, site=self.site, birth_cohort=self.birth_cohort, set_site_geography=False)
